is_container
Values
pub fn is_container() -> Bool
Detects whether the current process is running inside a container.
This could be a Docker, LXC or Podman container.
pub fn is_container() -> Bool
Detects whether the current process is running inside a container.
This could be a Docker, LXC or Podman container.